//////////////////////////////////////////////////////////////////////
//
//  Tablet PC Ink Sample
//
//  Copyright:
//      Alaska Software, (c) 2009. All rights reserved.
//
//  Contents:
//  This example is based on the "InkRecognition" sample that
//  ships with the Tablet PC SDK.
//
//  Note: This sample also shows how to use XbasePART names
//  to access parts which are childs of a dialog without
//  having declared a class. Only the dialog is referencing
//  the child parts in its child list. A child part is queried
//  using the :childFromName() method. (See XbpPartHandler)
//
//////////////////////////////////////////////////////////////////////

#include "appevent.ch"
#include "xbp.ch"
#include "fileio.ch"
#include "activex.ch"

#include "dialog.ch"
#include "inksdk.ch"

STATIC myRecognizers
STATIC myInkCollector

#PRAGMA LIBRARY( "ASCOM10.LIB" )

PROCEDURE Main

  LOCAL oMainDlg
  LOCAL nEvent, mp1, mp2, oXbp

  oMainDlg      := MainForm()

  oXbp          := oMainDlg:ChildFromName( ID_BTNRECOGNIZE )
  oXbp:Activate := {|| RecognizeInk()}

  oXbp          := oMainDlg:ChildFromName( ID_BTNSAVE )
  oXbp:Activate := {|| SaveInk()}

  InitInk()

   /*
   ** $TODO: create your application logic here
   */

  nEvent := xbeP_Quit
  DO WHILE nEvent != xbeP_Close
     nEvent := AppEvent( @mp1, @mp2, @oXbp )
     oXbp:handleEvent( nEvent, mp1, mp2 )
  ENDDO

  oMainDlg:destroy()

RETURN


/* Overloaded AppSys() procedure which does nothing.
 * This prevents creation of the default XbpCrt
 * console.
 */
PROCEDURE AppSys()
   SET CHARSET TO ANSI
RETURN


PROCEDURE InitInk()

    // Create the recognizers collection
    myRecognizers := CreateObject( "msinkaut.InkRecognizers" )

    // Create a new ink collector that uses the Frame's window
    myInkCollector      := CreateObject( "msinkaut.InkCollector" )
    myInkCollector:hWnd := SetAppWindow():ChildFromName(ID_STAFRAME):GetHWND()

    // Turn the ink collector on
    myInkCollector:Enabled = .T.

RETURN


// Save strokes entered in an Ink Edit control
// to a GIF image
PROCEDURE SaveInk()

 LOCAL aBin

    aBin := myInkCollector:Ink:Save( IPF_GIF, IPCM_Default )

    SaveByteArray( "testfile.gif", aBin )

RETURN


// Convert strokes entered in an Ink Edit control
// to text
PROCEDURE RecognizeInk()

    // Check to ensure that the user has at least one recognizer installed
    // Note that this is a preventive check - otherwise, an exception will
    // occur during recognition
    IF 0 == myRecognizers:Count
        MsgBox( "There are no handwriting recognizers installed.  You need to have at least one in order to run this sample." )
    ELSE
        // Note that the Strokes' ToString() method is a
        // shortcut  for retrieving the best match using the
        // default recognizer.  The same result can also be
        // obtained using the RecognizerContext.
        //
    dc_inspectobject(myInkCollector)
        SetAppWindow():ChildFromName(ID_MLETEXT):SetData( myInkCollector:Ink:Strokes:ToString() )

        // If the mouse is pressed, do not perform the recognition -
        // this prevents deleting a stroke that is still being drawn
        IF .NOT. myInkCollector:CollectingInk

            // Delete the ink from the ink collector
            myInkCollector:Ink:DeleteStrokes( myInkCollector:Ink:Strokes )

            // Force the Frame to redraw (so the deleted ink will go away)
            SetAppWindow():InvalidateRect()
        ENDIF
    ENDIF

RETURN


// Save an array of Bytes to file
PROCEDURE SaveByteArray( cFile, aBytes )

 LOCAL nFile := FCreate( cFile, FC_NORMAL )

   IF nFile == -1
      RETURN
   ENDIF

   FWrite(nFile, aBytes, Len(aBytes))

   FClose( nFile )

RETURN
